# Answer

gendata <- function(n, m, stdev, distype = 1) {
	result <- NULL
	if(distype == 1) {
		result <- rnorm(n, 0, 1)
	} else if (distype == 2) {
		result <- rt(n, 3)
	} else if (distype == 3) {
		result <- rchisq(n, 4)
	} else {
		stop("The distype argument is not valid.")
	}
	result <- (result - mean(result)) / sd(result)
	
	# Find empirical mean and sd
	temp <- rnorm(n, m, stdev)
	result <- sd(temp) * result + mean(temp)
	return(result)
}

set.seed(123321)
nrep <- 1000
b0 <- 0
bs <- c(0, 0.5, 1, 1.5)
ns <- c(50, 100, 200, 400)
ovresult <- NULL
for(k in 1:length(bs)){
	b1 <- bs[k]
	for(j in 1:length(ns)) {
		n <- ns[j]
		result <- matrix(NA, nrep, 3)
		for(i in 1:nrep) {
			x <- gendata(n, 0, 1, distype = 2)
			fy <- b0 + b1*x
			p <- exp(fy)/(1 + exp(fy))
			y <- rep(NA, n)
			for(w in 1:n) y[w] <- rbinom(1, 1, p[w])
			dat <- data.frame(x = x, y = y)
			out <- glm(y ~ x, data = dat, family = binomial(link = "logit"))
			sumout <- summary(out)
			result[i,] <- sumout[["coefficients"]][2, c(1, 2, 4)]
		}
		result <- cbind(b1, n, result)
		ovresult <- rbind(ovresult, result)
	}
}
sig <- ovresult[,5] < 0.05
ovresult <- cbind(ovresult, sig)
colnames(ovresult) <- c("b", "n", "est", "se", "p", "sig")
dput(ovresult, "key7ex6t.Rdata")
